//## begin module.cm preserve=no
//	  %X% %Q% %Z% %W%
//## end module.cm

//## begin module.cp preserve=no
//## end module.cp

//## Module: Einlage; Package specification
//	Headerfile
//## Subsystem: <Top Level>
//	Dateistruktur des Projektes mit Header- ud
//	Quellcodedateien
//	Erzeugte Dateien werden in MS-VC++ 6.0 Project
//	bernommen und dort ausprogrammiert
//	Der zustzlich  erzeugte Code bleibt auch nach
//	Hinzufgen von Komponenten im Modell erhalten!
//## Source file: c:\daten\uni\sofwaretechnik\stemabank\Einlage.h


#ifndef Einlage_h
#define Einlage_h 1

//## begin module.additionalIncludes preserve=no
//## end module.additionalIncludes

//## begin module.includes preserve=yes
//## end module.includes

// globals
#include "globals.h"

//## begin module.declarations preserve=no
//## end module.declarations

//## begin module.additionalDeclarations preserve=yes
//## end module.additionalDeclarations


//## Class: Einlage; Abstract
//	abstrakte Superklasse "Einlage"
//	Von ihr werden Subklassen erzeugt, die Einlagen des
//	Kunden darstellen,
//	Zusammenfassung einheitlicher Attribute und Operationen
//## Category: Kunden und Einlagenverwaltung
//## Subsystem: <Top Level>
//## Persistence: Transient
//## Cardinality/Multiplicity: n


class Einlage : public MFCOBJECT  //## Inherits: Subklasse von

{
  //## begin Einlage.initialDeclarations preserve=yes
  //## end Einlage.initialDeclarations

  public:
    //## Constructors (generated)
      Einlage();

      Einlage(const Einlage &right);

    //## Destructor (generated)
      ~Einlage();


    //## Other Operations (specified)
      //## Operation: gen_EinlagenID%937416389
      //	Erzeugt mit bergebenen Parametern: TYP und pKunde, die
      //	achstellige Einlagennummer und speichert diese.
      //	pKunde ist Zeiger auf eien Kunde und wird als Inhaber
      //	der Einlage gepeichert.
      BOOL gen_EinlagenID(Kunde* pKunde, BYTE Typ);

      //## Operation: get_Type%937416390
      //	gibt den TYP einer Einlage als vordefinierter BYTE-Wert
      //	zurck
      BYTE get_Type();

      //## Operation: check%937474104
      //	Operation berprft ob der bergebene Betrag gebucht
      //	werden kann oder nicht und liefert TRUE oder FALSE
      //	zurck.
      //	Bestand darf nicht negativ werden!
      //	Funktion ist virtual und wird von Subklassen je nach
      //	Bedarf berschrieben bzw. verfeinert.
      virtual BOOL check(float Betrag = 0);

      //## Operation: updateBestand%937474110
      //	Verndert den Bestand der Einlage um den bergebenen
      //	Betrag und liefert Erfolgsmeldung zurck!
      BOOL updateBestand(float Betrag = 0);

      //## Operation: zinsen%937734172
      //	Berechnet die Zinsen fr die bergebenen Monate und gibt
      //	diese zurck. Bei keiner Parameterbergabe werden die
      //	Zinsen pro 12 Monate, also pro Jahr errechnet. Der
      //	Bestand wird nicht verndert!
      virtual float zinsen(int Monate = 12);

      //## Operation: Serialize%937866640
      //	jede Datenklasse besitzt ihr eigene
      //	Serialisierungsfunktion.
      //	sie dient zur permanenten Speicherung des gesammten
      //	Datenbestandes der Bank.
      //	jede Klasse serialisiert sich praktisch selbst, indem
      //	sie ihre Daten serialisiert.
      void Serialize(CArchive& ar);

    //## Get and Set Operations for Has Relationships (generated)

      //## Documentation Einlage::Einlagennummer.has
      //	1 Objekt der Klasse Einlage besitzt jeweils 1 Objekt der
      //	EinlagenID
      //	Speicherung unter Einlagennummer per Wert
      EinlagenID get_Einlagennummer();

    //## Get and Set Operations for Class Attributes (generated)

      //## Attribute: Erstell_Dat
      //	beschreibt das Datum, an dem die Geldeinlage angelegt
      //	wurde.
      const CTime get_Erstell_Dat() const;
      void set_Erstell_Dat(const CTime value);

      //## Attribute: Status
      //	zeigt Stautus der Einlage an
      //	TRUE - fr Transaktionen bereit
      //	FALSE - gesperrt Grnde fr die Sperrung knnen in einer
      //	Anweisung des Kunden liegen, oder in einer berziehung
      //	der Einlage
      //	oder bei Festgeld, welches noch nicht fllig ist
      const BOOL get_Status() const;
      void set_Status(const BOOL value);

      //## Attribute: Bestand
      //	beschreibt den aktuellen Betand
      float get_Bestand();
      void set_Bestand(const float value);

      //## Attribute: Verzinsung
      //	beshreibt den Zinssatz (jhrlich) fr  die Geldeilage
      float get_Verzinsung();
      void set_Verzinsung(const float value);

      //## Attribute: LastEinlagenID
      //	Klassenvariable untersttzt Erzeugen der eindeutigen
      //	Einlagenummer
      //	wird im Konstruktor hochgezhlt
      static int get_LastEinlagenID();

    //## Get and Set Operations for Associations (generated)

      //## Association: EinlageKundenRel%37E79D200198
      //## Role: Einlage::InhaberID
      KundenID get_InhaberID();
      void set_InhaberID(const KundenID value);

    // Additional Public Declarations
      //## begin Einlage.public preserve=yes
	  	DECLARE_SERIAL(Einlage)
      //## end Einlage.public


  protected:
    // Additional Protected Declarations
      //## begin Einlage.protected preserve=yes
      //## end Einlage.protected


  private:
    // Additional Private Declarations
      //## begin Einlage.private preserve=yes
      //## end Einlage.private


  private:  //## implementation
    // Data Members for Has Relationships

      //## begin Einlage::Einlagennummer.has preserve=no  public: EinlagenID {1..1 -> 1..1VO}
      EinlagenID Einlagennummer;
      //## end Einlage::Einlagennummer.has

    // Data Members for Class Attributes

      //## begin Einlage::Erstell_Dat.attr preserve=no  public: CTime {U} 
      CTime Erstell_Dat;
      //## end Einlage::Erstell_Dat.attr

      //## begin Einlage::Status.attr preserve=no  public: BOOL {U} TRUE
      BOOL Status;
      //## end Einlage::Status.attr

      //## begin Einlage::Bestand.attr preserve=no  public: float {U} 0
      float Bestand;
      //## end Einlage::Bestand.attr

      //## begin Einlage::Verzinsung.attr preserve=no  public: float {U} 0
      float Verzinsung;
      //## end Einlage::Verzinsung.attr

      //## begin Einlage::LastEinlagenID.attr preserve=no  public: static int {U} 
      static int LastEinlagenID;
      //## end Einlage::LastEinlagenID.attr

    // Data Members for Associations

      //## Association: EinlageKundenRel%37E79D200198
      //## begin Einlage::InhaberID.role preserve=no  public: KundenID {1..n -> 1VHPN}
      KundenID InhaberID;
      //## end Einlage::InhaberID.role

    // Additional Implementation Declarations
      //## begin Einlage.implementation preserve=yes
      //## end Einlage.implementation

};



// Class Einlage 

//## Get and Set Operations for Has Relationships (inline)

inline EinlagenID Einlage::get_Einlagennummer()
{
  //## begin Einlage::get_Einlagennummer%.get preserve=no
  return Einlagennummer;
  //## end Einlage::get_Einlagennummer%.get
}

//## Get and Set Operations for Class Attributes (inline)

inline const CTime Einlage::get_Erstell_Dat() const
{
  //## begin Einlage::get_Erstell_Dat%.get preserve=no
  return Erstell_Dat;
  //## end Einlage::get_Erstell_Dat%.get
}

inline void Einlage::set_Erstell_Dat(const CTime value)
{
  //## begin Einlage::set_Erstell_Dat%.set preserve=no
  Erstell_Dat = value;
  //## end Einlage::set_Erstell_Dat%.set
}

inline const BOOL Einlage::get_Status() const
{
  //## begin Einlage::get_Status%.get preserve=no
  return Status;
  //## end Einlage::get_Status%.get
}

inline void Einlage::set_Status(const BOOL value)
{
  //## begin Einlage::set_Status%.set preserve=no
  Status = value;
  //## end Einlage::set_Status%.set
}

inline float Einlage::get_Bestand()
{
  //## begin Einlage::get_Bestand%.get preserve=no
  return Bestand;
  //## end Einlage::get_Bestand%.get
}

inline void Einlage::set_Bestand(const float value)
{
  //## begin Einlage::set_Bestand%.set preserve=no
  Bestand = value;
  //## end Einlage::set_Bestand%.set
}

inline float Einlage::get_Verzinsung()
{
  //## begin Einlage::get_Verzinsung%.get preserve=no
  return Verzinsung;
  //## end Einlage::get_Verzinsung%.get
}

inline void Einlage::set_Verzinsung(const float value)
{
  //## begin Einlage::set_Verzinsung%.set preserve=no
  Verzinsung = value;
  //## end Einlage::set_Verzinsung%.set
}

inline int Einlage::get_LastEinlagenID()
{
  //## begin Einlage::get_LastEinlagenID%.get preserve=no
  return LastEinlagenID;
  //## end Einlage::get_LastEinlagenID%.get
}

//## Get and Set Operations for Associations (inline)

inline KundenID Einlage::get_InhaberID()
{
  //## begin Einlage::get_InhaberID%.get preserve=no
  return InhaberID;
  //## end Einlage::get_InhaberID%.get
}

inline void Einlage::set_InhaberID(const KundenID value)
{
  //## begin Einlage::set_InhaberID%.set preserve=no
  InhaberID = value;
  //## end Einlage::set_InhaberID%.set
}





#endif


